#!/bin/sh
# Bryant Hansen

# get the MAC address of eth0 by calling/parsing ifconfig output
# initial 1-liner:
#    /sbin/ifconfig | grep eth0 | while read a b c d e ; do echo ${e//:/} ; done | tr "ABCDEF" "abcdef"

# current dSS method for obtaining mac address:
# MAC=`ifconfig eth0 | grep 'HWaddr' | awk '{ print $5}'`

ME="$(basename "$0")"
USAGE="$ME"

# next version:
#   - match MAC address by REGEX, rather than language-specific and distribution-specific strings
#   - extract MAC address from ifconfig line via last argument, rather than 5th argument
#   - insure lower-case output
#
MAC_REGEX="[ \t][0-9a-fA-F][0-9a-fA-F]:[0-9a-fA-F][0-9a-fA-F]:[0-9a-fA-F][0-9a-fA-F]:[0-9a-fA-F][0-9a-fA-F]:[0-9a-fA-F][0-9a-fA-F]:[0-9a-fA-F][0-9a-fA-F][ \t]*$"
SED_STRIP_TRAILING_SPACES="s/[ \t]*$//"
SED_GET_LAST_ARGUMENT="${SED_STRIP_TRAILING_SPACES};s/^.*[ \t]//"
SED_GREP_MAC_REGEX="/${MAC_REGEX}/p"
SED_STRIP_COLONS="s/://g"
SED_EXTRACT_AND_FORMAT_MAC="${SED_GREP_MAC_REGEX};${SED_GET_LAST_ARGUMENT};${SED_STRIP_COLONS}"
UPPER_HEX="ABCDEF"
LOWER_HEX="abcdef"

/sbin/ifconfig eth0                 | \
    sed -n "$SED_GREP_MAC_REGEX"    | \
    sed    "$SED_GET_LAST_ARGUMENT" | \
    sed    "$SED_STRIP_COLONS"      | \
    tr "$UPPER_HEX" "$LOWER_HEX"    | \
    head -n 1

###############################
# current working version:
###############################
#/sbin/ifconfig eth0 | \
#    grep "$MAC_REGEX" | \
#    sed "$SED_GET_LAST_ARGUMENT" | \
#    sed "s/://g" | \
#    tr "ABCDEF" "abcdef" | \
#    head -n 1
###############################

###############################
# dSS method:
###############################
#  /sbin/ifconfig eth0 | \
#      grep "$MAC_REGEX" | \
#      awk '{ print $5}' | \
#      sed "s/://g" | \
#      tr "ABCDEF" "abcdef" | \
#      head -n 1
###############################

# TODO: consider using the socket library via C to get this address
#   ifconfig output may vary depending on software version, language settings, etc
#   examples can be found at the following locations:
#     http://www.lainoox.com/find-mac-address/
#     http://www.linuxquestions.org/questions/programming-9/get-mac-address-given-a-specific-interface-452222/
